==> nextcloud-29.0.5.tgz: nextcloud/apps/oauth2/l10n/sr.js <==
OC.L10N.register(
    "oauth2",
    {
    "Your client is not authorized to connect. Please inform the administrator of your client." : "Вашем клијенту није одобрено повезивање. Обавестите администратора који је Ваш клијент.",
    "Your redirect URL needs to be a full URL for example: https://yourdomain.com/path" : "Адреса за преусмеравање мора бити пуна адреса, нпр: https://yourdomain.com/path",
    "OAuth 2.0" : "OAuth 2.0",
    "Allows OAuth2 compatible authentication from other web applications." : "Дозвољава OAuth2 компатибилну идентификацију са других веб апликација,",
    "The OAuth2 app allows administrators to configure the built-in authentication workflow to also allow OAuth2 compatible authentication from other web applications." : "OAuth2 апликација дозвољава администраторима да подесе уграђени след индетификације тако да дозвољава и OAuth2 компатибилну идентификацију са других веб апликација.",
    "OAuth 2.0 clients" : "OAuth 2.0 клијенти",
    "OAuth 2.0 allows external services to request access to {instanceName}." : "OAuth 2.0 омогућава спољним сервисима да захтевају приступ инстанци {instanceName}.",
    "Name" : "Име",
    "Redirection URI" : "Адреса за преусмеравање",
    "Client Identifier" : "Идентификација клијента",
    "Secret key" : "Тајни кључ ",
    "Delete client" : "Обриши клијента",
    "Add client" : "Додај клијента",
    "Add" : "Додај",
    "Delete" : "Обриши",
    "Show client secret" : "Прикажи клијентску лозинку",
    "Hide client secret" : "Сакриј клијентску тајну"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> nextcloud-31.0.9.tgz: nextcloud/apps/oauth2/l10n/sr.js <==
OC.L10N.register(
    "oauth2",
    {
    "Your client is not authorized to connect. Please inform the administrator of your client." : "Вашем клијенту није одобрено повезивање. Обавестите администратора који је Ваш клијент.",
    "Your redirect URL needs to be a full URL for example: https://yourdomain.com/path" : "Адреса за преусмеравање мора бити пуна адреса, нпр: https://yourdomain.com/path",
    "OAuth 2.0" : "OAuth 2.0",
    "Allows OAuth2 compatible authentication from other web applications." : "Дозвољава OAuth2 компатибилну идентификацију са других веб апликација,",
    "The OAuth2 app allows administrators to configure the built-in authentication workflow to also allow OAuth2 compatible authentication from other web applications." : "OAuth2 апликација дозвољава администраторима да подесе уграђени след индетификације тако да дозвољава и OAuth2 компатибилну идентификацију са других веб апликација.",
    "OAuth 2.0 clients" : "OAuth 2.0 клијенти",
    "OAuth 2.0 allows external services to request access to {instanceName}." : "OAuth 2.0 омогућава спољним сервисима да захтевају приступ инстанци {instanceName}.",
    "Name" : "Име",
    "Redirection URI" : "Адреса за преусмеравање",
    "Client Identifier" : "Идентификација клијента",
    "Secret key" : "Тајни кључ ",
    "Delete client" : "Обриши клијента",
    "Make sure you store the secret key, it cannot be recovered." : "Сачувајте тајни кључ, нећете моћи поново да му приступите.",
    "Add client" : "Додај клијента",
    "Add" : "Додај",
    "Show client secret" : "Прикажи клијентску лозинку",
    "Hide client secret" : "Сакриј клијентску тајну",
    "Delete" : "Обриши"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
